==> attention_0.1.0.tar.gz: attention/README.md <==
# attention
<!-- badges: start -->
[![License](https://img.shields.io/badge/license-GPLv3-brightgreen.svg)](https://www.gnu.org/licenses/gpl-3.0.html)
[![CRAN Version](https://www.r-pkg.org/badges/version/attention)](https://cran.r-project.org/package=attention)
[![R build status](https://github.com/bquast/attention/workflows/R-CMD-check/badge.svg)](https://github.com/bquast/attention/actions?workflow=R-CMD-check)
[![Codecov test coverage](https://codecov.io/gh/bquast/attention/branch/main/graph/badge.svg)](https://app.codecov.io/gh/bquast/attention?branch=main)
[![Total RStudio Cloud Downloads](https://cranlogs.r-pkg.org/badges/grand-total/attention?color=brightgreen)](https://cran.r-project.org/package=attention)
[![RStudio Cloud Downloads](https://cranlogs.r-pkg.org/badges/attention?color=brightgreen)](https://cran.r-project.org/package=attention)
<!-- badges: end -->

Self-Attention algorithm helper functions and demonstration vignettes of increasing depth on how to construct the Self-Attention algorithm.

The **development** version, to be used **at your peril**, can be installed from [GitHub](https://github.com/bquast/attention) using the [remotes](https://cran.r-project.org/package=remotes) package.

```r
if (!require('remotes')) install.packages('remotes')
remotes::install_github('bquast/attention')
```

Development
-------------
Development takes place on the GitHub page.

<https://github.com/bquast/attention>

Bugs can be filed on the issues page on GitHub.

<https://github.com/bquast/attention/issues>

==> attention_0.2.0.tar.gz: attention/README.md <==
# attention
<!-- badges: start -->
[![License](https://img.shields.io/badge/license-GPLv3-brightgreen.svg)](https://www.gnu.org/licenses/gpl-3.0.html)
[![CRAN Version](https://www.r-pkg.org/badges/version/attention)](https://cran.r-project.org/package=attention)
[![R build status](https://github.com/bquast/attention/workflows/R-CMD-check/badge.svg)](https://github.com/bquast/attention/actions?workflow=R-CMD-check)
[![Codecov test coverage](https://codecov.io/gh/bquast/attention/branch/main/graph/badge.svg)](https://app.codecov.io/gh/bquast/attention?branch=main)
[![Total RStudio Cloud Downloads](https://cranlogs.r-pkg.org/badges/grand-total/attention?color=brightgreen)](https://cran.r-project.org/package=attention)
[![RStudio Cloud Downloads](https://cranlogs.r-pkg.org/badges/attention?color=brightgreen)](https://cran.r-project.org/package=attention)
<!-- badges: end -->

Self-Attention algorithm helper functions and demonstration vignettes of increasing depth on how to construct the Self-Attention algorithm.

## CRAN install
The package can be installed from [CRAN](https://cran.r-project.org/package=remotes) using:
```r
install.packages('attention')
```

## Preview version
The **development** version, to be used **at your peril**, can be installed from [GitHub](https://github.com/bquast/attention) using the [remotes](https://cran.r-project.org/package=remotes) package.

```r
if (!require('remotes')) install.packages('remotes')
remotes::install_github('bquast/attention')
```

## Development
Development takes place on the GitHub page.

<https://github.com/bquast/attention>

Bugs can be filed on the issues page on GitHub.

<https://github.com/bquast/attention/issues>
